pub struct JsonArray<'a> {
inner: &'a ArrayRef,
}Fields
inner: &'a ArrayRefImplementations
Sourceimpl JsonArray<'_>
impl JsonArray<'_>
Sourcepub fn try_get_value(&self, i: usize) -> Result<Value>
pub fn try_get_value(&self, i: usize) -> Result<Value>
Try to get the value (as a Value) at the index i.
Sourcepub fn project_to_v2(
&self,
field: &Field,
target: &DataType,
) -> Result<ArrayRef>
pub fn project_to_v2( &self, field: &Field, target: &DataType, ) -> Result<ArrayRef>
Projects a physical JSON2 array to a logical query type.
TODO(LFC) Supersede project_to_v2 to project_to.
Sourcepub fn rewrite_to_v2(
&self,
field: &Field,
logical_settings: &JsonSettings,
target_layout: &JsonSettings,
) -> Result<ArrayRef>
pub fn rewrite_to_v2( &self, field: &Field, logical_settings: &JsonSettings, target_layout: &JsonSettings, ) -> Result<ArrayRef>
Rewrites a JSON2 array from the current physical layout into the specified v2 physical layout.
Sourcepub fn rewrite_to_v2_with_type_hint_mismatch_policy(
&self,
field: &Field,
logical_settings: &JsonSettings,
target_layout: &JsonSettings,
policy: TypeHintMismatchPolicy,
) -> Result<ArrayRef>
pub fn rewrite_to_v2_with_type_hint_mismatch_policy( &self, field: &Field, logical_settings: &JsonSettings, target_layout: &JsonSettings, policy: TypeHintMismatchPolicy, ) -> Result<ArrayRef>
Rewrites a JSON2 array to the specified v2 physical layout using the given type hint mismatch policy.
fn json2_values(&self) -> Result<Vec<Value>>
Sourcepub fn project_to(&self, target: &DataType) -> Result<ArrayRef>
pub fn project_to(&self, target: &DataType) -> Result<ArrayRef>
Projects this JSON array to target for query evaluation.
Unlike [Self::widen_to], projection tolerates lossy conversions:
- source fields not present in
targetare discarded; - fields missing from the source are filled with typed null arrays;
- values incompatible with the target type become NULL.
Projection is applied recursively to structs and lists. Input nulls remain NULL. Errors unrelated to type incompatibility, such as invalid JSONB, are returned.
fn project_values_to(&self, to_type: &DataType) -> Result<ArrayRef>